/*
 *  AccelHandler.java
 *	Part of the Spirograph problem set.
 *
 * Developed for "Rethinking CS101", a project of Lynn Andrea Stein's AP Group.
 * For more information, see <a href="http://www.ai.mit.edu/projects/cs101">the
 * CS101 homepage</a> or email <las@ai.mit.edu>.
 *
 * Copyright (C) 1998 Massachusetts Institute of Technology.
 * Please do not redistribute without obtaining permission.
 */

package Spirograph;

/**
 * This class contains a Thread that continuously prompts the
 * user's class for an acceleration and passes this information
 * on to an instance of DotPanel.
 *
 * <P>Copyright (C) 1998 Massachusetts Institute of Technology.
 * 
 * @author  Luis Sarmenta, lfgs@cag.lcs.mit.edu
 * @author  Henry Wong, henryw@mit.edu
 * @version  $Id: AccelHandler.java,v 1.6 1998/07/24 16:58:39 tparnell Exp $
 * 
 * @see Accelerator
 * @see DotPanel
 * @see Coord
 */
public class AccelHandler implements Runnable {
  /** Position control mode */  
  public static final int POSMODE = 1;
  /** Velocity control mdde */
  public static final int VELMODE = 2;
  /** Acceleration control mode */
  public static final int ACCELMODE = 3;
    
  private Accelerator Accel;    
  private DotPanel myPanel;
  private Coord myCoord;
  private Coord otherCoord;
    
  /** Creates a new AccelHandler.  Does not start a new Thread. */
  public AccelHandler (Accelerator Accel, DotPanel myPanel,
		       Coord myCoord, Coord otherCoord) {
    this.Accel = Accel;
    this.myPanel = myPanel;
    this.myCoord = myCoord;
    this.otherCoord = otherCoord;
  }
    
  /**
   * Changes the current Accelerator.
   *
   * @param Accel the new Accelerator
   */
  public synchronized void setAccel (Accelerator Accel) {
    // This method is synchronized with part of the while(true)
    // loop to keep people from switching the Accelerator while
    // it is being queried.

    System.out.println ("New Accelerator set.");
    this.Accel = Accel;
  }

  /**
   * Prompt the user's class for an accleration and pass the info on to
   * our DotPanel.
   */    
  public void run() {
    while (true) {
      synchronized (this) {
	myCoord.setValue( Accel.act( myCoord.getPos(), 
				     myCoord.getVel(), 
				     otherCoord.getPos(), 
				     otherCoord.getVel(), 
				     myCoord.getMaxPos()
				     ));
      }
      try {
	Thread.sleep((int)(100*Spirograph.TIMESTEP));
	//Thread.yield();
      } catch (Exception e) {
	System.out.println ("Oops.");
      }
    }
  }

}

/*
 * $Log: AccelHandler.java,v $
 * Revision 1.6  1998/07/24 16:58:39  tparnell
 * Placate new javadoc behavior
 *
 * Revision 1.5  1998/07/24 15:20:06  tparnell
 * Added javadoc.  Removed some deprecated code.  Fixed a few minor bugs.
 *
 * Revision 1.4  1998/07/23 15:09:17  natashao
 * Added javadoc and a few comments.
 *
 */




