/*
 *  CodeBox.java
 *	Part of the Spirograph problem set.
 *
 * Developed for "Rethinking CS101", a project of Lynn Andrea Stein's AP Group.
 * For more information, see <a href="http://www.ai.mit.edu/projects/cs101">the
 * CS101 homepage</a> or email <las@ai.mit.edu>.
 *
 * Copyright (C) 1998 Massachusetts Institute of Technology.
 * Please do not redistribute without obtaining permission.
 */

package Spirograph;

import java.awt.*;
import java.awt.event.*;

/**
 * This class pops up the Code editing area. The Code editing area
 * has two big text areas where the students can enter code, as well
 * as two smaller text areas (that initially start off hidden) that
 * can be used to enter fields.
 *
 * <P>This code also creates an instance of AdvProg, creates all of the
 * appropriate listeners and passes them to the instance.
 * This code does not actually process and/or compile the user's code;
 * that is done by instances of CodeMerger, which are added to the
 * big buttons that say, "Load Horizontal Code" and "Load Vertical Code" 
 *
 * <P>Copyright (C) 1998 Massachusetts Institute of Technology.
 *
 * @author  Luis Sarmenta, lfgs@cag.lcs.mit.edu
 * @author  Henry Wong, henryw@mit.edu
 * @version  $Id: CodeBox.java,v 1.6 1998/07/24 16:58:41 tparnell Exp $
 * 
 * @see AccelHandler
 * @see CodeMerger
 */
public class CodeBox extends Frame {

  /** the default width */
  static final int WIDTH = 800;
  /** the default height */
  static final int HEIGHT = 530;

  // Note: \u002F == '/'
  private final static String STUDENT_START = "\u002F*<-- STUDENT CODE BEGINS HERE -->*\u002F\n";
  private final static String STUDENT_END = "\u002F*<-- STUDENT CODE ENDS HERE -->*\u002F\n";

  //The strings to put around the code when writing to a file
  static final String OPEN = "public class ";
  static final String DEC = " implements Spirograph.Accelerator {\n" + STUDENT_START;
  static final String DEC2 = STUDENT_END +
  "\n  public double act (double pos, double vel, double otherPos," +
  " double otherVel, double maxPos) {\n" + STUDENT_START;
  static final String CLOSE = STUDENT_END + "  }\n}";
  
  //The names of the two files to read/write/compile
  static final String HSTRING = "HorizRule";
  static final String VSTRING = "VertRule";

  /** Construct a new CodeBox.  If no font is specified, use a default. */
  public CodeBox(TextArea hArea, TextArea vArea, TextArea hFields,
		 TextArea vFields, CodeMerger hMerger, CodeMerger vMerger,
		 AccelHandler xHandler, AccelHandler yHandler) {
	
    this(hArea, vArea, hFields, vFields, hMerger, vMerger,
	 xHandler, yHandler, Spirograph.DEFAULTFONT);
  }
    
  /** Construct a CodeBox.  Use the specified font. */
  public CodeBox(TextArea hArea, TextArea vArea, TextArea hFields,
		 TextArea vFields, CodeMerger hMerger,
		 CodeMerger vMerger, final AccelHandler xHandler,
		 final AccelHandler yHandler, Font f) {

    this.setFont(f);
    this.setTitle("Spirograph Code Editor");
	
    Panel top = new Panel();
    top.setLayout(new BorderLayout(10,10));
    top.add ("West", new MultiLabel (
				     "Note: The variable pos holds the position of the dot along each " +
				     "axis, and the variable vel holds the velocity of the dot\n " +
				     "along each axis. The variables otherPos and otherVel hold "+
				     "the position and velocity of the dot along the other axis."));
    Button quit = new Button("Quit");
    quit.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent ae) {
	System.exit(0);
      }
    });
    top.add("Center", quit);
	
    // Set up fields and labels for horiz area
    Label hFieldLabel=new Label ("Enter horizontal rule fields here.");
	
    Panel hTop = new Panel();
    hTop.setLayout(new BorderLayout(10,10));
    hTop.add("North", hFieldLabel);
    hTop.add("South", hFields);

    Panel hMid = new Panel();
    hMid.setLayout(new BorderLayout(10,10));
    hMid.add("North", new Label ("Enter horizontal rule below:"));
    hMid.add("South", hArea );

    Checkbox hBoth = new Checkbox( "Use this rule for both dimensions", false );
    Button hDone = new Button("Compile and Load Horizontal Code");
    hDone.addActionListener(hMerger);
    Panel hBot = new Panel();
    hBot.setLayout(new BorderLayout(10,3));
    hBot.add("North", hBoth );
    hBot.add("South", hDone );
	
    // Add fields and labels, text area and Done button to horiz area
    Panel hContainer = new Panel();	
    hContainer.setLayout (new BorderLayout(10,10));
    hContainer.add("North", hTop);
    hContainer.add("Center", hMid);
    hContainer.add("South", hBot);

    // Set up fields and labels for vertical area
    Label vFieldLabel=new Label ("Enter vertical rule fields here.");
	
    Panel vTop = new Panel();
    vTop.setLayout(new BorderLayout(10,10));
    vTop.add("North", vFieldLabel);
    vTop.add("South", vFields);

    Panel vMid = new Panel();
    vMid.setLayout(new BorderLayout(10,10));
    vMid.add("North",new Label ("Enter vertical rule below:"));
    vMid.add("South",vArea );

    Checkbox vBoth = new Checkbox( "Use this rule for both dimensions", false );
    Button vDone = new Button("Compile and Load Vertical Code");    	
    vDone.addActionListener(vMerger);
    Panel vBot = new Panel();
    vBot.setLayout(new BorderLayout(10,3));
    vBot.add("North", vBoth );
    vBot.add("South", vDone );

    // Add fields and labels, text area and Done button to vert area
    Panel vContainer = new Panel();	
    vContainer.setLayout (new BorderLayout(10,10));
    vContainer.add("North", vTop);
    vContainer.add("Center", vMid);
    vContainer.add("South", vBot);

    // Set up ItemListeners for "Advanced Programming"
    OneRuleListener hOnly = new OneRuleListener
      (hArea, vArea, hFields, vFields, hDone, vDone, vBoth, hMerger);
	
    OneRuleListener vOnly = new OneRuleListener
      (vArea, hArea, vFields, hFields, vDone, hDone, hBoth, vMerger);
	
    hBoth.addItemListener(hOnly);
    vBoth.addItemListener(vOnly);


    // Read in and parse horizontal code from file
    String hString = Util.readFile(CodeBox.HSTRING+".java");     	
    if (!(hString.equals(""))) {
      hFields.setText(liftText(hString, " implements Accelerator {\n", 
			       "\npublic double act (double pos, double vel, "+
			       "double otherPos, double otherVel, double maxPos) {\n"));
      hArea.setText(liftText(hString, "\npublic double act "+
			     "(double pos, double vel, double otherPos, double otherVel, "+
			     "double maxPos) {\n", 
			     "\n}\n}"));
    }

    // Read in and parse vertical code from file
    String vString = Util.readFile(CodeBox.VSTRING+".java"); 	
    if (!(vString.equals(""))) {
      vFields.setText(liftText(vString, " implements Accelerator {\n", 
			       "\npublic double act (double pos, double vel, "+
			       "double otherPos, double otherVel, double maxPos) {\n"));
      vArea.setText(liftText(vString, "\npublic double act "+
			     "(double pos, double vel, double otherPos, double otherVel, "+
			     "double maxPos) {\n", 
			     "\n}\n}"));
    }

	
    // Do final Layout
    this.setLayout(new BorderLayout(10,10));

    this.add ("West", hContainer);
    this.add ("East", vContainer);
    this.add ("South", top);
	
    this.setSize(CodeBox.WIDTH,CodeBox.HEIGHT);
    this.show();
  }

  private String liftText(String src, String start, String end)
  {
    int startpos = src.indexOf(start) + start.length();
    int endpos = src.indexOf(end);
    if(startpos > 0 && endpos > 0)
      return src.substring(startpos, endpos);
    else
      return "";
  }

}

/*
 * $Log: CodeBox.java,v $
 * Revision 1.6  1998/07/24 16:58:41  tparnell
 * Placate new javadoc behavior
 *
 * Revision 1.5  1998/07/24 15:51:24  tparnell
 * Added javadoc.  Removed some deprecated code.  Fixed a few minor bugs.
 *
 * Revision 1.4  1998/07/23 15:09:24  natashao
 * Added javadoc and a few comments.
 *
 */



