/*
 *  CodeMerger.java
 *	Part of the Spirograph problem set.
 *
 * Developed for "Rethinking CS101", a project of Lynn Andrea Stein's AP Group.
 * For more information, see <a href="http://www.ai.mit.edu/projects/cs101">the
 * CS101 homepage</a> or email <las@ai.mit.edu>.
 *
 * Copyright (C) 1998 Massachusetts Institute of Technology.
 * Please do not redistribute without obtaining permission.
 */

package Spirograph;

import java.awt.event.*;
import java.awt.*;
import cs101.util.*;

/** 
 * This class implements a listener that is added to the "Load
 * Horizontal Code." and "Load Vertical Code" buttons on the Code
 * Box. The CodeMerger reads the text off the text fields, writes it
 * to a file along with the appropriate headers, compiles the file and
 * creates a new instance of the resulting class. This instance is
 * then passed in to the AccelHandlers as a new Accelerator to use. <p>
 *
 * Copyright (C) 1998 Massachusetts Institute of Technology.
 *
 * @author  Luis Sarmenta, lfgs@cag.lcs.mit.edu
 * @author  Henry Wong, henryw@mit.edu
 * @version  $Id: CodeMerger.java,v 1.9 1999/07/27 04:17:09 mharder Exp $
 * 
 * @see AccelHandler
 * @see SpiroUtils
 */


public class CodeMerger implements ActionListener {

  private String ruleName; 
    
  // The text area to read code off of.
  private TextArea myTA;

  // The text area to read the fields off of.
  private TextArea myFields;
  private AccelHandler myAccelHandler, otherAccelHandler;
  private boolean useAsBoth = false;

  // Compiles the source files created by the student
  private CompileManager compileManager;

  // Loads the compiled classes.  Must be used to load classes that have
  // changed after they have been loaded once.
  // private MultiClassLoader multiClassLoader;
  
  public CodeMerger (String ruleName, TextArea myTA, TextArea myFields,
		     AccelHandler myAccelHandler,
		     AccelHandler otherAccelHandler) {
    this.ruleName = ruleName;
    this.myTA = myTA;
    this.myFields = myFields;
    this.myAccelHandler = myAccelHandler;
    this.otherAccelHandler = otherAccelHandler;
    this.compileManager = new JavacCompileManager();
    //    this.multiClassLoader = new FileClassLoader("");
  }

  /**
   * This is used when the option to use the same rule for both the
   * vertical and horizontal acceleration is selected
   */
  public void setBoth(boolean useAsBoth) {
    this.useAsBoth = useAsBoth;
  }

  /** 
   * Creates a .java file containing the rules and fields written by
   * the students, then compiles it.  If compiling the file does not
   * cause errors, a new instance of the Class is created, then cast to
   * an Accelerator and passed to the accel handlers.
   *
   * @see cs101.util.CompileManager
   */
  public void actionPerformed(ActionEvent ae) {
    Util.writeFile(ruleName+".java", CodeBox.OPEN + ruleName +
		   CodeBox.DEC + myFields.getText() + CodeBox.DEC2 +
		   myTA.getText() + CodeBox.CLOSE);
    
    Class ruleClass;
    try {      
      this.compileManager.compile(this.ruleName);
      // We must create a new multiClassLoader every time we
      // want to load the class.  If we don't, we get a 
      // java.lang.linkageError.
      MultiClassLoader multiClassLoader = new FileClassLoader("");
      ruleClass = multiClassLoader.forceLoadClass(this.ruleName);
    } catch (CompilerException ce) {
      System.out.println(ce.getMessage());
      return;
    } catch (java.io.IOException ioe) {
      System.out.println(ioe);
      return;
    } catch (ClassNotFoundException cnfe) {
      System.out.println(cnfe);
      return;
    }
    
    Object rule;
    try {
      rule = ruleClass.newInstance();
    } catch (Exception e) {
      System.out.println(e);
      return;
    }

    this.myAccelHandler.setAccel((Accelerator) rule);

    System.out.println ("Use as both rules: " + useAsBoth);
    if (useAsBoth) {
      this.otherAccelHandler.setAccel((Accelerator) rule);
    }
    System.out.println ("Done loading code.");
  }
}

/*
 * $Log: CodeMerger.java,v $
 * Revision 1.9  1999/07/27 04:17:09  mharder
 * Moved MultiClassLoader and FileClassLoader from package
 * Spirograph to cs101.util.  Changed spec of CompileManager to
 * compile class and return nothing.  Changed this file to reflect this change.  This solved the problem of not getting the behavior of
 * rules that were compiled more than once.
 *
 * Revision 1.8  1999/05/15 05:57:22  mharder
 * Added "@see cs101.util.CompileManger" to javadoc
 *
 * Revision 1.7  1999/05/15 05:49:14  mharder
 * Converted to use cs101.util.CompileManager.  Modified documentation
 * to reflect this change.
 *
 * Revision 1.6  1998/07/24 16:58:42  tparnell
 * Placate new javadoc behavior
 *
 * Revision 1.5  1998/07/24 15:51:28  tparnell
 * Added javadoc.  Removed some deprecated code.  Fixed a few minor bugs.
 *
 * Revision 1.4  1998/07/23 15:09:26  natashao
 * Added javadoc and a few comments.
 * 
 */


