/*
 * Coord.java
 * part of the Spirograph.java problem set
 *
 * Developed for "Rethinking CS101", a project of Lynn Andrea Stein's AP Group.
 * For more information, see <a href="http://www.ai.mit.edu/projects/cs101">the
 * CS101 homepage</a> or email <las@ai.mit.edu>.
 *
 * Copyright (C) 1996 Massachusetts Institute of Technology.
 * Please do not redistribute without obtaining permission.
 */

package Spirograph;

import java.util.*;
import java.awt.*;

/**
 * This class holds information regarding one dimension of the ball.
 * It has methods to update the position of the ball, as well as
 * methods to get and set certain variables.
 *
 * <P>Copyright (C) 1996 Massachusetts Institute of Technology.
 *
 * @author  Luis Sarmenta, lfgs@cag.lcs.mit.edu
 * @author  Henry Wong, henryw@mit.edu
 * @version $Id: Coord.java,v 1.6 1998/07/24 16:58:42 tparnell Exp $ 
 *
 * @see AccelHandler
 * @see Spirograph
 */
public class Coord {
    
  private double pos = 0;
  private double vel = 0;
  private double accel = 0;
  private double maxPos = Spirograph.WIDTH;

  private int accelMode = AccelHandler.POSMODE;

  /** Determines the current mode of operation, either position,
      velocity, or accleration control. */
  public int getMode() { return accelMode; }

  /** Sets the current mode.  Legal parameter values are
      AccelHandler.POSMODE, AccelHandler.VELMODE, or
      AccelHandler.ACCELMODE. */
  public void setMode(int mode) {
    switch( mode ) {
    case AccelHandler.POSMODE: 
      setVel(0.0D);
      // fall through

    case AccelHandler.VELMODE:
      setAccel(0.0D);
      // fall through

    default:
      accelMode = mode;
      break;
    }
  }

  public double getMaxPos() { return maxPos; }
  public void setMaxPos( double pos ) { maxPos = pos; }
	

  public double getPos() { return pos; }
  public void setPos(double pos) { this.pos = pos; }

  public double getVel() { return vel; }
  public void setVel(double vel) { this.vel = vel; }

  public double getAccel() { return accel; }
  public void setAccel(double accel) { this.accel = accel; }                

  public void setValue(double val)
  {
    switch( accelMode ) {
    case AccelHandler.POSMODE: 
      setPos(val);
      break;
    case AccelHandler.VELMODE: 
      setVel(val);
      break;
    case AccelHandler.ACCELMODE: 
      setAccel(val);
      break;
    }
  }

  /**
   *  Calculates the acceleration of the ball by taking
   *  the acceleration that was set and adding it to the combined
   *  accelerations resulting from each of the different gravitational
   *  fields.
   */
  public void nextStep (Vector v, double step) {
    double finalAccel = accel;
	
    for (Enumeration e = v.elements(); e.hasMoreElements();) {
      Point data  = (Point)e.nextElement();

      // I just use these to make the math formula a little
      // easier to follow, they aren't really needed.
      int dx = data.x;
      int dr = data.y;

      if (dr != 0) {	    
	finalAccel += Spirograph.GRAV*dx/Math.pow(dr,3);
      }

      // If dr == 0 just ignore it...
    }
	
    vel = vel + (finalAccel * step);
    pos = pos + (vel * step);
  }
}

/*
 * $Log: Coord.java,v $
 * Revision 1.6  1998/07/24 16:58:42  tparnell
 * Placate new javadoc behavior
 *
 * Revision 1.5  1998/07/24 15:51:29  tparnell
 * Added javadoc.  Removed some deprecated code.  Fixed a few minor bugs.
 *
 * Revision 1.4  1998/07/23 15:09:27  natashao
 * Added javadoc and a few comments.
 *
 */


