/*
 * MultiLabel.java
 * part of the Spirograph problem set
 *
 * Developed for "Rethinking CS101", a project of Lynn Andrea Stein's AP Group.
 * For more information, see <a href="http://www.ai.mit.edu/projects/cs101">the
 * CS101 homepage</a> or email <las@ai.mit.edu>.
 *
 * Copyright (C) 1996 Massachusetts Institute of Technology.
 * Please do not redistribute without obtaining permission.
 */

package Spirograph;

import java.awt.*;
import java.util.*;

/*
 * This class creates a self-sizing Canvas that prints a multi-line
 * String.  It can be given a specific font when created, or use a
 * default.
 *
 * <P>Copyright (c) 1998 Massachusetts Institute of Technology
 *
 * @author  Luis Sarmenta, lfgs@cag.lcs.mit.edu
 * @author  Henry Wong, henryw@mit.edu
 * @version  $Id: MultiLabel.java,v 1.6 1998/07/24 16:58:47 tparnell Exp $
 *
 * @see Spirograph 
 */
public class MultiLabel extends Canvas {
    public static final int MARGINWIDTH = 10;
    public static final int MARGINHEIGHT = 10;

    private String lines[];
    private int numLines;
    private int maxWidth = 0;
    private int lineHeight;
    private int lineAscent;
        
    public MultiLabel(String str) {
	this(str, Spirograph.DEFAULTFONT);	
    }

    public MultiLabel(String str, Font f) {	
	this.setFont(f);
	// Start off parsing str and measuring stuff.
	
	StringTokenizer t = new StringTokenizer(str, "\n");
	numLines = t.countTokens();	    
	lines = new String[numLines];
	for (int i = 0; i < numLines; i++) {
	    lines[i] = t.nextToken();
	}
	
	// Move on to font specific stuff.
	
	FontMetrics fm =this.getToolkit().getFontMetrics(this.getFont());
	lineHeight = fm.getHeight();
	lineAscent = fm.getAscent();
	for (int i = 0; i < numLines; i++) {
	    if (fm.stringWidth(lines[i]) > maxWidth) {
		maxWidth = fm.stringWidth(lines[i]);
	    }
	}
	
	this.setSize(maxWidth + 2*MultiLabel.MARGINWIDTH,
		     lineHeight * numLines + 2*MultiLabel.MARGINHEIGHT);
    }

    public void paint(Graphics g) {
	int y = MultiLabel.MARGINHEIGHT + lineAscent;
	
	for (int i = 0; i < numLines; i++) {
	    g.drawString(lines[i], MultiLabel.MARGINWIDTH, y);
	    y += lineHeight;
	}
    }
}    


/*
 * $Log: MultiLabel.java,v $
 * Revision 1.6  1998/07/24 16:58:47  tparnell
 * Placate new javadoc behavior
 *
 * Revision 1.5  1998/07/24 15:52:18  tparnell
 * Added javadoc.  Removed some deprecated code.  Fixed a few minor bugs.
 *
 * Revision 1.4  1998/07/23 15:09:33  natashao
 * Added javadoc and a few comments.
 *
 */




