/*
 * ResetMenu.java 
 * Part of the Spirograph problem set
 *
 * Developed for "Rethinking CS101", a project of Lynn Andrea Stein's AP Group.
 * For more information, see <a href="http://www.ai.mit.edu/projects/cs101">the
 * CS101 homepage</a> or email <las@ai.mit.edu>.
 *
 * Copyright (C) 1996 Massachusetts Institute of Technology.
 * Please do not redistribute without obtaining permission.
 */

package Spirograph;

/**
 * This class creates a pop up menu that allows the user to reset different
 * things. All of the event handlers are passed from the DotFrame.
 *
 * <P>Copyright (c) 1998 Massachusetts Institute of Technology
 *
 * @author  Luis Sarmenta, lfgs@cag.lcs.mit.edu
 * @author  Henry Wong, henryw@mit.edu
 * @version  $Id: ResetMenu.java,v 1.6 1998/07/24 16:58:48 tparnell Exp $
 * 
 * @see Spirograph
 */

import java.awt.*;
import java.awt.event.*;

public class ResetMenu extends Frame {
    Button lines = new Button();
    Label linesLab = new Label("Click here to clear lines.");
    Panel linesCont = new Panel();
    
    Button grav = new Button ();
    Label gravLab = new Label("Click here to clear the gravity sources.");
    Panel gravCont = new Panel();
    
    Button pos = new Button();
    Label posLab = new Label("Click here to stop the ball and move it " +
			     "back to the center.");
    Panel posCont = new Panel();
    
    Button all = new Button();
    Label allLab = new Label("Click here to do all of the above.");
    Panel allCont = new Panel();
    
    public ResetMenu() {
	this(Spirograph.DEFAULTFONT);
    }

    // I use containers and a grid layout so that the bottom button will
    // span the entire width of the window. Doing it this way is easier
    // than using a GridBagLayout
    
    public ResetMenu(Font f) {
	Button close = new Button ("Close this window");

	close.addActionListener(new ActionListener() {
	    public void actionPerformed(ActionEvent ae) {
		ResetMenu.this.setVisible(false);
	    }
	});

	linesCont.setLayout(new FlowLayout(FlowLayout.LEFT));
	linesCont.add(lines);
	linesCont.add(linesLab);

	gravCont.setLayout(new FlowLayout(FlowLayout.LEFT));
	gravCont.add(grav);
	gravCont.add(gravLab);

	posCont.setLayout(new FlowLayout(FlowLayout.LEFT));
	posCont.add(pos);
	posCont.add(posLab);

	allCont.setLayout(new FlowLayout(FlowLayout.LEFT));
	allCont.add(all);
	allCont.add(allLab);
	
	this.setFont(f);
	this.setTitle("Reset Menu");
	this.setLayout(new GridLayout(5,1));
	this.add(linesCont);
	this.add(gravCont);
	this.add(posCont);
	this.add(allCont);
	this.add(close);

	this.pack();
    }

    public void addListeners(ActionListener lList, ActionListener gList,
			     ActionListener pList, ActionListener aList) {
	lines.addActionListener(lList);
	grav.addActionListener(gList);
	pos.addActionListener(pList);
	all.addActionListener(aList);
    }

}

/*
 * $Log: ResetMenu.java,v $
 * Revision 1.6  1998/07/24 16:58:48  tparnell
 * Placate new javadoc behavior
 *
 * Revision 1.5  1998/07/24 15:52:21  tparnell
 * Added javadoc.  Removed some deprecated code.  Fixed a few minor bugs.
 *
 * Revision 1.4  1998/07/23 15:09:35  natashao
 * Added javadoc and a few comments.
 *
 */
