/*
 * SetPosGravListener.java 
 * Part of the Spirograph problem set
 *
 * Developed for "Rethinking CS101", a project of Lynn Andrea Stein's AP Group.
 * For more information, see <a href="http://www.ai.mit.edu/projects/cs101">the
 * CS101 homepage</a> or email <las@ai.mit.edu>.
 *
 * Copyright (C) 1996 Massachusetts Institute of Technology.
 * Please do not redistribute without obtaining permission.
 */

package Spirograph;

/**
 * This code implements a listener which listens to the DotPanel and
 * waits for mouse clicks. Depending on what "mode" it is in, the
 * SetPosGravListener will either add in a new gravitational source,
 * reposition the dot or do nothing. The mode of this listener is change
 * by some of the button listeners in the AdvEnv instance.
 *
 * Copyright (c) 1998 Massachusetts Institute of Technology
 *
 * @author  Luis Sarmenta, lfgs@cag.lcs.mit.edu
 * @author  Henry Wong, henryw@mit.edu
 * @version  $Id: SetPosGravListener.java,v 1.6 1998/07/24 16:58:50 tparnell Exp $
 * 
 * @see Coord
 * @see DotPanel
 */

import java.awt.*;
import java.awt.event.*;

public class SetPosGravListener implements MouseListener {
    public static final int NONE = 0;
    public static final int POS = 1;
    public static final int GRAV = 2;

    private Coord xCoord;
    private Coord yCoord;
    private DotPanel myPanel;
    private int mode = SetPosGravListener.POS;
    
    public SetPosGravListener(Coord xCoord, Coord yCoord, DotPanel myPanel){
	this.xCoord = xCoord;
	this.yCoord = yCoord;
	this.myPanel = myPanel;
    }

    // If the mouse is pressed do something depending on what mode you're in.
    public void mousePressed(MouseEvent e) {
	double newX = e.getX()-myPanel.curWidth()/2;
	double newY = myPanel.curHeight()/2-e.getY();

	if (mode == SetPosGravListener.POS) {

	    if ((!(myPanel.getCirc())) ||
		((Math.pow(2*newX/myPanel.curWidth(),2) +
		  Math.pow(2*newY/myPanel.curHeight(),2)) < 1)) {
		// Only let the user place inside the circle if in
		// circular mode
		
		System.out.println ("Ball moved to " + newX + ":" + newY);
		
		xCoord.setPos(newX);
		yCoord.setPos(newY);
	    } else {
		System.out.println ("You can't place the ball there.");
	    }
	} else if (mode == SetPosGravListener.GRAV) {

	    System.out.println ("Adding grav spot at: " + newX + ":" + newY);

	    myPanel.addGrav((int)newX, (int)newY);
	}
	    
	myPanel.paintBuf();
    }

    // Some methods that the interface requires.
    public void mouseReleased(MouseEvent e) {}
    public void mouseClicked(MouseEvent e) {}
    public void mouseEntered(MouseEvent e) {}
    public void mouseExited(MouseEvent e) {}

    public void setMode (int mode) {
	this.mode = mode;
    }
    
}

/*
 * $Log: SetPosGravListener.java,v $
 * Revision 1.6  1998/07/24 16:58:50  tparnell
 * Placate new javadoc behavior
 *
 * Revision 1.5  1998/07/24 15:52:21  tparnell
 * Added javadoc.  Removed some deprecated code.  Fixed a few minor bugs.
 *
 * Revision 1.4  1998/07/23 15:09:36  natashao
 * Added javadoc and a few comments.
 *
 */


