/*
 * SetVListener.java 
 * Part of the Spirograph problem set
 *
 * Developed for "Rethinking CS101", a project of Lynn Andrea Stein's AP Group.
 * For more information, see <a href="http://www.ai.mit.edu/projects/cs101">the
 * CS101 homepage</a> or email <las@ai.mit.edu>.
 *
 * Copyright (C) 1996 Massachusetts Institute of Technology.
 * Please do not redistribute without obtaining permission.
 */

package Spirograph;

import java.awt.*;
import java.awt.event.*;

/**
 * This class listens to the set velocity button in the AdvEnv
 * Frame and sets the velocity of the dot with whatever text is in
 * the TextArea.
 *
 * <P>Copyright (c) 1998 Massachusetts Institute of Technology
 *
 * @author  Luis Sarmenta, lfgs@cag.lcs.mit.edu
 * @author  Henry Wong, henryw@mit.edu
 * @version  $Id: SetVListener.java,v 1.6 1998/07/24 16:58:50 tparnell Exp $
 * 
 * @see Coord
 * @see Spirograph 
 */
public class SetVListener implements ActionListener {
  private TextField xVel;
  private TextField yVel;
  private Coord xCoord;
  private Coord yCoord;
    
  public SetVListener(TextField xVel, TextField yVel, Coord xCoord,
		      Coord yCoord) {
    this.xVel = xVel;
    this.yVel = yVel;
    this.xCoord = xCoord;
    this.yCoord = yCoord;
  }
    
  public void actionPerformed(ActionEvent ae) {
    double newX;
    double newY;

    try {
      newX = Double.valueOf(xVel.getText()).doubleValue();
      newY = Double.valueOf(yVel.getText()).doubleValue();
    } catch (NumberFormatException e) {
      System.out.println ("Error setting velocity");
      return;
    }	
	
    // There is a maximum velocity that I set, b/c otherwise if the
    // ball is moving too fast things start to get really messy and
    // inaccurate.
	
    if (Math.sqrt(Math.pow(newX,2) + Math.pow(newY,2)) >
	Spirograph.MAXVEL) {
      newX = Spirograph.MAXVEL*newX/(newX+newY);
      newY = Spirograph.MAXVEL*newY/(newX+newY);
      xCoord.setVel(newX);
      yCoord.setVel(newY);
      xVel.setText(String.valueOf(Math.round(newX)));
      yVel.setText(String.valueOf(Math.round(newY)));
	    
      System.out.println ("Velocity too high, being coerced down.");
    }
	
    xCoord.setVel(newX);
    yCoord.setVel(newY);
    System.out.println ("Velocity set");

  }
}


/*
 * $Log: SetVListener.java,v $
 * Revision 1.6  1998/07/24 16:58:50  tparnell
 * Placate new javadoc behavior
 *
 * Revision 1.5  1998/07/24 15:52:22  tparnell
 * Added javadoc.  Removed some deprecated code.  Fixed a few minor bugs.
 *
 * Revision 1.4  1998/07/23 15:09:36  natashao
 * Added javadoc and a few comments.
 *
 */




