/*
 * SpiroUtils.java 
 * Part of the Spirograph problem set
 *
 * Developed for "Rethinking CS101", a project of Lynn Andrea Stein's AP Group.
 * For more information, see <a href="http://www.ai.mit.edu/projects/cs101">the
 * CS101 homepage</a> or email <las@ai.mit.edu>.
 *
 * Copyright (C) 1996 Massachusetts Institute of Technology.
 * Please do not redistribute without obtaining permission.
 */

package Spirograph;

import java.io.*;

/**
 * This class contained a bunch of Utilities that were specific to this
 * problem set, but only one of them turned out to be neccesary.
 *
 * <P>Copyright (c) 1998 Massachusetts Institute of Technology
 *
 * @author  Luis Sarmenta, lfgs@cag.lcs.mit.edu
 * @author  Henry Wong, henryw@mit.edu
 * @version  $Id: SpiroUtils.java,v 1.8 1999/07/27 04:17:10 mharder Exp $
 * 
 * @see Accelerator
 */
public abstract class SpiroUtils {
  public static int CUR = 0;


  public static void delFile( String fileName )
  {
    File file = new File( fileName );
		
    if ( file != null )
      file.delete();
  }

  public static void copyFiles( String src, String dest )
  {
    try {
      FileInputStream srcInput = new FileInputStream( src );
      FileOutputStream destOutput = new FileOutputStream( dest, false );
		
      byte[] buf = new byte[1024];
      int bytesRead = 0;
		
      do {
	bytesRead = srcInput.read( buf );
	if ( bytesRead > 0 )
	  {
	    destOutput.write( buf, 0, bytesRead );
	  }
      } while ( bytesRead > 0 );
			
      srcInput.close();
      destOutput.close();
    } catch ( IOException e )
      {
	System.out.println( "Error copying " + src + " to " + dest +": " + e );
      }
  }

  /**
   * This method reads in a file, creates an Object from that
   * class and casts it to an Accelerator. <p>
   *
   * Class.forName(String) caches names, if I ask it to reread
   * a file that the user has changed it will return the old
   * version of that file. Therefore, I use some system calls
   * to copy the file to a new name, read it in and erase it. <p>
   *
   * This method is only used to load the classes, if any, specified
   * as command line arguments when the program is started.  It is <em>not</em>
   * used to load the classes that are compiled during the execution
   * of the program.  To do this, a cs101.util.MultiClassLoader is used.
   *
   * @see cs101.util.MultiClassLoader
   */ 
  public static Accelerator createAccel(String className) {
    Object temp = null;
    Class c = null;
    
    // read in temporary file
    try {
      //      MultiClassLoader loader = new FileClassLoader("");
      //loader.monitorOn = true;
      
      //      c = loader.forceLoadClass(className);
      
      // We do not need to use a MultiClassLoader here.  Class.forName works
      // fine, since it is the first time we are loading the class.  Only
      // use the MultiClassLoader when loading a class that has changed.
      c = Class.forName(className);
      System.out.println( "Loaded class " + c.getName() );

      temp = c.newInstance();
	    
    } catch (Exception e) {
      System.out.println (e);
      System.out.println ("Class "+ className + " not found.");
      return(null);
    }

    if (!(temp instanceof Accelerator)) {
      System.out.println ("Class doesn't implement Accelerator");
      return(null);
    }

    return (Accelerator)temp;
  }
}


/*
 * $Log: SpiroUtils.java,v $
 * Revision 1.8  1999/07/27 04:17:10  mharder
 * Moved MultiClassLoader and FileClassLoader from package
 * Spirograph to cs101.util.  Changed spec of CompileManager to
 * compile class and return nothing.  Changed this file to reflect this change.  This solved the problem of not getting the behavior of
 * rules that were compiled more than once.
 *
 * Revision 1.7  1999/05/15 05:49:14  mharder
 * Converted to use cs101.util.CompileManager.  Modified documentation
 * to reflect this change.
 *
 * Revision 1.6  1998/07/24 16:58:51  tparnell
 * Placate new javadoc behavior
 *
 * Revision 1.5  1998/07/24 15:52:23  tparnell
 * Added javadoc.  Removed some deprecated code.  Fixed a few minor bugs.
 *
 * Revision 1.4  1998/07/23 15:09:37  natashao
 * Added javadoc and a few comments.
 *
 */

