/*
 * Spirograph.java
 * part of the Spirograph problem set
 *
 * Developed for "Rethinking CS101", a project of Lynn Andrea Stein's AP Group.
 * For more information, see <a href="http://www.ai.mit.edu/projects/cs101">the
 * CS101 homepage</a> or email <las@ai.mit.edu>.
 *
 * Copyright (C) 1998 Massachusetts Institute of Technology.
 * Please do not redistribute without obtaining permission.
 */

package Spirograph;

import java.io.*;
import java.awt.*;

/**
 * This class handles a lot of the initialization for the Spirograph.
 * It creates an instance of DotFrame and CodeBox and creates
 * instances of the name passed in on the command line.
 * It also creates the CodeBox and the AccelHandlers and passes
 * them to the appropriate objects. <p>
 *
 * Copyright (c) 1998 Massachusetts Institute of Technology
 *
 * @author  Luis Sarmenta, lfgs@cag.lcs.mit.edu
 * @author  Henry Wong, henryw@mit.edu
 * @version  $Id: Spirograph.java,v 1.6 1998/07/24 16:58:52 tparnell Exp $
 * 
 * @see AccelHandler
 * @see CodeBox
 * @see DotFrame
 *
 * Copyright (C) 1998 Massachusetts Institute of Technology. 
 */
public class Spirograph {
  public static final int HEIGHT = 400;
  public static final int WIDTH = 400;
  /** Size of the dot as it will appear in the GUI. */
  public static final int BALLSIZE = 10;
  /** Minimum timestep for updates. */
  public static final double TIMESTEP = 1;    
  public static final int GRAV = 1000;
  /** Maximum dot velocity allowed. */
  public static final double MAXVEL = 60;
  public static final int FOCUSSIZE = 6;

  /** Problem set wide default font. */
  public static final Font DEFAULTFONT = new Font("Plain", Font.PLAIN, 12);
    
  private Accelerator xAccel, yAccel;
  private Coord xCoord = new Coord();
  private Coord yCoord = new Coord();
  private DotPanel myPanel;
  private AccelHandler xHandler, yHandler;
  private DotFrame myFrame;
  private TextArea hArea = new TextArea(15,50);
  private TextArea vArea = new TextArea(15,50);
  private TextArea hFields = new TextArea
  ("",2,30,TextArea.SCROLLBARS_VERTICAL_ONLY);
  private TextArea vFields = new TextArea
  ("",2,30,TextArea.SCROLLBARS_VERTICAL_ONLY);
  private CodeBox cb;
    
  /** 
   * Attempt to construct a new Spirograph with the given Accleration
   * Handlers.  Abort if either handler cannot be created.
   */
  public Spirograph (String xArg, String yArg) {
	
    if ( xArg == null ) {
      xAccel = new Dummy();
    } else {
      System.out.println ("Trying to get class: " + xArg);	
      xAccel = SpiroUtils.createAccel(xArg);	
    }
	
    if ( yArg == null )
      yAccel = new Dummy();
    else {
      System.out.println ("Trying to get class: " + yArg);	
      yAccel = SpiroUtils.createAccel(yArg);
    }

    if ((xAccel == null)||(yAccel == null)) {
      System.exit(0);
    }
	
    myPanel = new DotPanel(xCoord, yCoord);
       
    xHandler = new AccelHandler(xAccel, myPanel, xCoord, yCoord);
    yHandler = new AccelHandler(yAccel, myPanel, yCoord, xCoord);

    cb = new CodeBox(hArea, vArea, hFields, vFields,
      new CodeMerger(CodeBox.HSTRING, hArea, hFields,
		     xHandler, yHandler), 
		     new CodeMerger(CodeBox.VSTRING, vArea, vFields, 
				    yHandler, xHandler), xHandler, yHandler);
    
    myFrame = new DotFrame(xHandler, yHandler, myPanel, xCoord, yCoord);
  }
}

/*
 * $Log: Spirograph.java,v $
 * Revision 1.6  1998/07/24 16:58:52  tparnell
 * Placate new javadoc behavior
 *
 * Revision 1.5  1998/07/24 15:52:24  tparnell
 * Added javadoc.  Removed some deprecated code.  Fixed a few minor bugs.
 *
 * Revision 1.4  1998/07/23 15:09:37  natashao
 * Added javadoc and a few comments.
 *
 */







